==> haskell-hi-file-parser-0.1.8.0-31.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hi-file-parser
version:              0.1.8.0
visibility:           public
id:                   hi-file-parser-0.1.8.0-5Zv7u0hbmSjBbq944J7HE
key:                  hi-file-parser-0.1.8.0-5Zv7u0hbmSjBbq944J7HE
license:              BSD-3-Clause
copyright:            Copyright 2015-2025, Stack contributors
maintainer:
    Michael Snoyman <michael@snoyman.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Hussein Ait-Lahcen <hussein.aitlahcen@gmail.com>
homepage:             https://github.com/commercialhaskell/hi-file-parser#readme
synopsis:             Parser for GHC'\''s *.hi files
description:
    A parser for GHC'\''s *.hi files. Extracts information about dependencies and
    usage of files.

category:             Development
abi:                  3f89e06af211121005e5f037e714e6de
exposed:              True
exposed-modules:      HiFileParser
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hi-file-parser-0.1.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hi-file-parser-0.1.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hi-file-parser-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hi-file-parser
hs-libraries:         HShi-file-parser-0.1.8.0-5Zv7u0hbmSjBbq944J7HE
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3 mtl-2.3.1
    rio-0.1.22.0-2S3DgnoH0cl6ZJdvxjSsI5 text-2.0.2
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hi-file-parser-0.1.8.0-32-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hi-file-parser
version:              0.1.8.0
visibility:           public
id:                   hi-file-parser-0.1.8.0-8qisbnW7BoWAxztuEmkbHw
key:                  hi-file-parser-0.1.8.0-8qisbnW7BoWAxztuEmkbHw
license:              BSD-3-Clause
copyright:            Copyright 2015-2025, Stack contributors
maintainer:
    Michael Snoyman <michael@snoyman.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Hussein Ait-Lahcen <hussein.aitlahcen@gmail.com>
homepage:             https://github.com/commercialhaskell/hi-file-parser#readme
synopsis:             Parser for GHC'\''s *.hi files
description:
    A parser for GHC'\''s *.hi files. Extracts information about dependencies and
    usage of files.

category:             Development
abi:                  a29a9fc3341afae0bfdd3d23ca6f6549
exposed:              True
exposed-modules:      HiFileParser
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hi-file-parser-0.1.8.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hi-file-parser-0.1.8.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hi-file-parser-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hi-file-parser
hs-libraries:         HShi-file-parser-0.1.8.0-8qisbnW7BoWAxztuEmkbHw
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3 mtl-2.3.1
    rio-0.1.22.0-9YWPFaDDA8QAvZjRU1ibSo text-2.0.2
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock

haddock-html:         /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
